.wp-block-pullquote.is-style-solid-color blockquote p {
  font-size: 32px;
}
.wp-block-pullquote.is-style-solid-color .wp-block-pullquote__citation {
  text-transform: none;
  font-style: normal;
}

.wp-block-pullquote__citation {
  color: inherit;
}