/**
 * Colors
 */
/**
 * Typography
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
 * Breakpoints & Media Queries
 */
/**
*  Converts a hex value into the rgb equivalent.
*
* @param {string} hex - the hexadecimal value to convert
* @return {string} comma separated rgb values
*/
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Breakpoint mixins
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
/**
 * Creates a checkerboard pattern background to indicate transparency.
 * @param {String} $size - The size of the squares in the checkerboard pattern. Default is 12px.
 */
:root {
  --wp-block-synced-color: #7a00df;
  --wp-block-synced-color--rgb: 122, 0, 223;
  --wp-bound-block-color: var(--wp-block-synced-color);
  --wp-editor-canvas-background: #ddd;
  --wp-admin-theme-color: #007cba;
  --wp-admin-theme-color--rgb: 0, 124, 186;
  --wp-admin-theme-color-darker-10: rgb(0, 107, 160.5);
  --wp-admin-theme-color-darker-10--rgb: 0, 107, 160.5;
  --wp-admin-theme-color-darker-20: #005a87;
  --wp-admin-theme-color-darker-20--rgb: 0, 90, 135;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  :root {
    --wp-admin-border-width-focus: 1.5px;
  }
}

.admin-ui-page {
  display: flex;
  height: 100%;
  background-color: var(--wpds-color-bg-surface-neutral-strong, #ffffff);
  color: var(--wpds-color-fg-content-neutral, #1e1e1e);
  position: relative;
  z-index: 1;
  flex-flow: column;
  text-wrap: pretty;
}

.admin-ui-page__header {
  padding: var(--wpds-dimension-padding-lg, 16px) var(--wpds-dimension-padding-2xl, 24px);
  border-bottom: var(--wpds-border-width-xs, 1px) solid var(--wpds-color-stroke-surface-neutral-weak, #e0e0e0);
  background: var(--wpds-color-bg-surface-neutral-strong, #ffffff);
  position: sticky;
  top: 0;
  z-index: 1;
}

.admin-ui-page__header-title {
  font-family: var(--wpds-font-family-heading, -apple-system, system-ui, "Segoe UI", "Roboto", "Oxygen-Sans", "Ubuntu", "Cantarell", "Helvetica Neue", sans-serif);
  font-size: var(--wpds-font-size-xl, 20px);
  font-weight: var(--wpds-font-weight-medium, 499);
  line-height: var(--wpds-font-line-height-xl, 32px);
  margin: 0;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.admin-ui-page__sidebar-toggle-slot:empty {
  display: none;
}

.admin-ui-page__header-subtitle {
  padding-block-end: var(--wpds-dimension-padding-xs, 4px);
  color: var(--wpds-color-fg-content-neutral-weak, #6d6d6d);
  font-size: var(--wpds-font-size-md, 13px);
  line-height: var(--wpds-font-line-height-md, 24px);
  margin: 0;
}

.admin-ui-page__content {
  flex-grow: 1;
  overflow: auto;
  display: flex;
  flex-direction: column;
}

.admin-ui-page__content.has-padding {
  padding: var(--wpds-dimension-padding-lg, 16px) var(--wpds-dimension-padding-2xl, 24px);
}

.show-icon-labels .admin-ui-page__header-actions .components-button.has-icon {
  width: auto;
  padding: 0 var(--wpds-dimension-padding-xs, 4px);
}

.show-icon-labels .admin-ui-page__header-actions .components-button.has-icon svg {
  display: none;
}

.show-icon-labels .admin-ui-page__header-actions .components-button.has-icon::after {
  content: attr(aria-label);
  font-size: var(--wpds-font-size-sm, 12px);
}

/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
.admin-ui-breadcrumbs__list {
  list-style: none;
  padding: 0;
  margin: 0;
  gap: 0;
  font-size: 15px;
  min-height: 32px;
  font-weight: 500;
}

.admin-ui-breadcrumbs__list li:not(:last-child)::after {
  content: "/";
  margin: 0 8px;
}

.admin-ui-breadcrumbs__list h1 {
  font-size: inherit;
  line-height: inherit;
}

/**
 * Colors
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
.interface-complementary-area-header {
  background: #fff;
  padding-left: 8px;
  gap: 4px;
}

.interface-complementary-area-header .interface-complementary-area-header__title {
  margin: 0 0 0 auto;
}

/**
 * Typography
 */
/**
 * Breakpoints & Media Queries
 */
/**
*  Converts a hex value into the rgb equivalent.
*
* @param {string} hex - the hexadecimal value to convert
* @return {string} comma separated rgb values
*/
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Breakpoint mixins
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
/**
 * Creates a checkerboard pattern background to indicate transparency.
 * @param {String} $size - The size of the squares in the checkerboard pattern. Default is 12px.
 */
.interface-complementary-area {
  background: #fff;
  color: #1e1e1e;
  height: 100%;
  overflow: auto;
}

@media (min-width: 782px) {
  .interface-complementary-area {
    width: 280px;
  }
}
.interface-complementary-area .components-panel {
  border: none;
  position: relative;
  z-index: 0;
}

.interface-complementary-area .components-panel__header {
  position: sticky;
  top: 0;
  z-index: 1;
}

.interface-complementary-area .components-panel__header.editor-sidebar__panel-tabs {
  top: 0;
}

.interface-complementary-area p:not(.components-base-control__help, .components-form-token-field__help) {
  margin-top: 0;
}

.interface-complementary-area h2 {
  font-size: 13px;
  font-weight: 499;
  color: #1e1e1e;
  margin-bottom: 1.5em;
}

.interface-complementary-area h3 {
  font-size: 11px;
  text-transform: uppercase;
  font-weight: 499;
  color: #1e1e1e;
  margin-bottom: 1.5em;
}

.interface-complementary-area hr {
  border-top: none;
  border-bottom: 1px solid #f0f0f0;
  margin: 1.5em 0;
}

.interface-complementary-area div.components-toolbar-group,
.interface-complementary-area div.components-toolbar {
  box-shadow: none;
  margin-bottom: 1.5em;
}

.interface-complementary-area div.components-toolbar-group:last-child,
.interface-complementary-area div.components-toolbar:last-child {
  margin-bottom: 0;
}

.interface-complementary-area .block-editor-skip-to-selected-block:focus {
  top: auto;
  left: 10px;
  bottom: 10px;
  right: auto;
}

.interface-complementary-area__fill {
  height: 100%;
}

@media (min-width: 782px) {
  body.js.is-fullscreen-mode {
    margin-top: -32px;
    height: calc(100% + 32px);
  }
  body.js.is-fullscreen-mode #adminmenumain,
  body.js.is-fullscreen-mode #wpadminbar {
    display: none;
  }
  body.js.is-fullscreen-mode #wpcontent,
  body.js.is-fullscreen-mode #wpfooter {
    margin-right: 0;
  }
}
html.interface-interface-skeleton__html-container {
  position: fixed;
  width: 100%;
}

@media (min-width: 782px) {
  html.interface-interface-skeleton__html-container:not(:has(.is-zoom-out)) {
    position: initial;
    width: initial;
  }
}
.interface-interface-skeleton {
  display: flex;
  flex-direction: row;
  height: auto;
  max-height: 100%;
  position: fixed;
  top: 46px;
  right: 0;
  left: 0;
  bottom: 0;
}

@media (min-width: 783px) {
  .interface-interface-skeleton {
    top: 32px;
  }
  .is-fullscreen-mode .interface-interface-skeleton {
    top: 0;
  }
}
.interface-interface-skeleton__editor {
  display: flex;
  flex-direction: column;
  flex: 0 1 100%;
  overflow: hidden;
}

.interface-interface-skeleton { /* Set left position when auto-fold is not on the body element. */
  right: 0;
}

@media (min-width: 783px) {
  .interface-interface-skeleton {
    right: 160px;
  }
}
.auto-fold .interface-interface-skeleton { /* Auto fold is when on smaller breakpoints, nav menu auto collapses. */ }

@media (min-width: 783px) {
  .auto-fold .interface-interface-skeleton {
    right: 36px;
  }
}
@media (min-width: 961px) {
  .auto-fold .interface-interface-skeleton {
    right: 160px;
  }
}
/* Sidebar manually collapsed. */
.folded .interface-interface-skeleton {
  right: 0;
}

@media (min-width: 783px) {
  .folded .interface-interface-skeleton {
    right: 36px;
  }
}
body.is-fullscreen-mode .interface-interface-skeleton {
  right: 0 !important;
}

.interface-interface-skeleton__body {
  position: relative;
  flex-grow: 1;
  display: flex;
  overflow: auto;
  overscroll-behavior-y: none;
}

@media (min-width: 782px) {
  .has-footer .interface-interface-skeleton__body {
    padding-bottom: 25px;
  }
}
.interface-interface-skeleton__content {
  flex-grow: 1;
  display: flex;
  flex-direction: column;
  overflow: auto;
  z-index: 20;
}

@media (min-width: 782px) {
  .interface-interface-skeleton__content {
    z-index: auto;
  }
}
.interface-interface-skeleton__secondary-sidebar,
.interface-interface-skeleton__sidebar {
  flex-shrink: 0;
  position: absolute;
  z-index: 100000;
  top: 0;
  right: 0;
  bottom: 0;
  background: #fff;
  color: #1e1e1e;
  width: auto;
}

@media (min-width: 782px) {
  .interface-interface-skeleton__secondary-sidebar,
  .interface-interface-skeleton__sidebar {
    position: relative !important;
  }
}
.interface-interface-skeleton__sidebar {
  border-top: 1px solid #e0e0e0;
  overflow: hidden;
}

@media (min-width: 782px) {
  .interface-interface-skeleton__sidebar {
    box-shadow: 1px 0 0 0 rgba(0, 0, 0, 0.133);
    outline: 1px solid transparent;
  }
}
.interface-interface-skeleton__secondary-sidebar {
  border-top: 1px solid #e0e0e0;
  left: 0;
}

@media (min-width: 782px) {
  .interface-interface-skeleton__secondary-sidebar {
    box-shadow: -1px 0 0 0 rgba(0, 0, 0, 0.133);
    outline: 1px solid transparent;
  }
}
.interface-interface-skeleton__header {
  flex-shrink: 0;
  height: auto;
  box-shadow: 0 1px 0 0 rgba(0, 0, 0, 0.133);
  z-index: 30;
  color: #1e1e1e;
  outline: 1px solid transparent;
}

.interface-interface-skeleton__footer {
  height: auto;
  flex-shrink: 0;
  border-top: 1px solid #e0e0e0;
  color: #1e1e1e;
  position: absolute;
  bottom: 0;
  right: 0;
  width: 100%;
  background-color: #fff;
  z-index: 90;
  display: none;
}

@media (min-width: 782px) {
  .interface-interface-skeleton__footer {
    display: flex;
  }
}
.interface-interface-skeleton__footer .block-editor-block-breadcrumb {
  z-index: 30;
  display: flex;
  background: #fff;
  height: 24px;
  align-items: center;
  font-size: 13px;
  padding: 0 18px;
}

.interface-interface-skeleton__actions {
  z-index: 100000;
  position: fixed !important;
  top: -9999em;
  bottom: auto;
  right: auto;
  left: 0;
  color: #1e1e1e;
  background: #fff;
  width: 100vw;
}

@media (min-width: 782px) {
  .interface-interface-skeleton__actions {
    width: 280px;
  }
}
.interface-interface-skeleton__actions:focus, .interface-interface-skeleton__actions:focus-within {
  top: auto;
  bottom: 0;
}

.is-entity-save-view-open .interface-interface-skeleton__actions:focus, .is-entity-save-view-open .interface-interface-skeleton__actions:focus-within {
  top: 46px;
}

@media (min-width: 782px) {
  .is-entity-save-view-open .interface-interface-skeleton__actions:focus, .is-entity-save-view-open .interface-interface-skeleton__actions:focus-within {
    border-right: 1px solid #ddd;
    top: 32px;
  }
  .is-fullscreen-mode .is-entity-save-view-open .interface-interface-skeleton__actions:focus, .is-fullscreen-mode .is-entity-save-view-open .interface-interface-skeleton__actions:focus-within {
    top: 0;
  }
}
.interface-pinned-items {
  display: flex;
}

.interface-pinned-items .components-button {
  display: none;
  margin: 0;
}

.interface-pinned-items .components-button[aria-controls="edit-post:document"], .interface-pinned-items .components-button[aria-controls="edit-post:block"], .interface-pinned-items .components-button[aria-controls="edit-site:template"], .interface-pinned-items .components-button[aria-controls="edit-site:block-inspector"] {
  display: flex;
}

.interface-pinned-items .components-button svg {
  max-width: 24px;
  max-height: 24px;
}

@media (min-width: 600px) {
  .interface-pinned-items .components-button {
    display: flex;
  }
}
.interface-pinned-items {
  gap: 8px;
}

.wp-block[data-type="core/widget-area"] {
  max-width: 700px;
  margin-right: auto;
  margin-left: auto;
}
.wp-block[data-type="core/widget-area"] .components-panel__body > .components-panel__body-title {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  margin: 0;
  height: 48px;
  position: relative;
  z-index: 1;
  background: #fff;
  transform: translateZ(0);
}
.wp-block[data-type="core/widget-area"] .components-panel__body > .components-panel__body-title:hover {
  background: #fff;
}
.wp-block[data-type="core/widget-area"] .block-list-appender.wp-block {
  width: initial;
  position: relative;
}
.wp-block[data-type="core/widget-area"] .editor-styles-wrapper .wp-block.wp-block.wp-block.wp-block.wp-block {
  max-width: 100%;
}
.wp-block[data-type="core/widget-area"] .components-panel__body.is-opened {
  padding: 0;
}

.blocks-widgets-container .wp-block-widget-area__inner-blocks.editor-styles-wrapper {
  margin: 0;
  padding: 0;
}
.blocks-widgets-container .wp-block-widget-area__inner-blocks.editor-styles-wrapper > .block-editor-block-list__layout {
  margin-top: -48px;
  padding: 72px 16px 16px;
  min-height: 32px;
}

.wp-block-widget-area__highlight-drop-zone {
  outline: var(--wp-admin-border-width-focus) solid var(--wp-admin-theme-color);
}

body.is-dragging-components-draggable .wp-block[data-type="core/widget-area"] .components-panel__body > .components-panel__body-title,
body.is-dragging-components-draggable .wp-block[data-type="core/widget-area"] .components-panel__body > .components-panel__body-title * {
  pointer-events: none;
}

.edit-widgets-error-boundary {
  margin: auto;
  max-width: 780px;
  padding: 20px;
  margin-top: 64px;
  box-shadow: 0 5px 15px rgba(0, 0, 0, 0.08), 0 15px 27px rgba(0, 0, 0, 0.07), 0 30px 36px rgba(0, 0, 0, 0.04), 0 50px 43px rgba(0, 0, 0, 0.02);
}

.edit-widgets-header {
  display: flex;
  align-items: center;
  justify-content: space-between;
  height: 64px;
  overflow: auto;
  background: #fff;
}
@media (min-width: 600px) {
  .edit-widgets-header {
    overflow: visible;
  }
}
.edit-widgets-header .selected-block-tools-wrapper {
  overflow: hidden;
  display: flex;
  align-items: center;
  height: 64px;
}
.edit-widgets-header .selected-block-tools-wrapper .block-editor-block-contextual-toolbar {
  border-bottom: 0;
  height: 100%;
}
.edit-widgets-header .selected-block-tools-wrapper .block-editor-block-toolbar {
  height: 100%;
  padding-top: 17px;
}
.edit-widgets-header .selected-block-tools-wrapper .block-editor-block-toolbar .components-button:not(.block-editor-block-mover-button) {
  height: 32px;
}
.edit-widgets-header .selected-block-tools-wrapper .components-toolbar-group,
.edit-widgets-header .selected-block-tools-wrapper .components-toolbar {
  border-left: none;
}
.edit-widgets-header .selected-block-tools-wrapper .components-toolbar-group::after,
.edit-widgets-header .selected-block-tools-wrapper .components-toolbar::after {
  content: "";
  width: 1px;
  height: 24px;
  background-color: #ddd;
  margin-top: 4px;
  margin-right: 8px;
}
.edit-widgets-header .selected-block-tools-wrapper .components-toolbar-group .components-toolbar-group.components-toolbar-group::after,
.edit-widgets-header .selected-block-tools-wrapper .components-toolbar .components-toolbar-group.components-toolbar-group::after {
  display: none;
}
.edit-widgets-header .selected-block-tools-wrapper .block-editor-block-mover.is-horizontal .block-editor-block-mover-button {
  height: 32px;
  overflow: visible;
}
@media (min-width: 600px) {
  .edit-widgets-header .selected-block-tools-wrapper .block-editor-block-mover:not(.is-horizontal) .block-editor-block-mover__move-button-container {
    position: relative;
    top: -10px;
  }
}

.edit-widgets-header__navigable-toolbar-wrapper {
  display: flex;
  align-items: center;
  justify-content: center;
  flex-shrink: 2;
  padding-left: 8px;
  padding-right: 16px;
  overflow: hidden;
  height: 64px;
}

.edit-widgets-header__title {
  font-size: 20px;
  padding: 0;
  margin: 0 0 0 20px;
}

.edit-widgets-header__actions {
  display: flex;
  align-items: center;
  padding-left: 4px;
}
@media (min-width: 600px) {
  .edit-widgets-header__actions {
    padding-left: 8px;
  }
}
.edit-widgets-header__actions {
  gap: 8px;
}

.edit-widgets-header-toolbar {
  gap: 8px;
  margin-left: 8px;
}
.edit-widgets-header-toolbar > .components-button.has-icon.has-icon.has-icon,
.edit-widgets-header-toolbar > .components-dropdown > .components-button.has-icon.has-icon {
  height: 32px;
  min-width: 32px;
  padding: 4px;
}
.edit-widgets-header-toolbar > .components-button.has-icon.has-icon.has-icon.is-pressed,
.edit-widgets-header-toolbar > .components-dropdown > .components-button.has-icon.has-icon.is-pressed {
  background: #1e1e1e;
}
.edit-widgets-header-toolbar > .components-button.has-icon.has-icon.has-icon:focus:not(:disabled),
.edit-widgets-header-toolbar > .components-dropdown > .components-button.has-icon.has-icon:focus:not(:disabled) {
  box-shadow: 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color), inset 0 0 0 1px #fff;
  outline: 1px solid transparent;
}
.edit-widgets-header-toolbar > .components-button.has-icon.has-icon.has-icon::before,
.edit-widgets-header-toolbar > .components-dropdown > .components-button.has-icon.has-icon::before {
  display: none;
}

.edit-widgets-header-toolbar__inserter-toggle.edit-widgets-header-toolbar__inserter-toggle {
  padding-right: 8px;
  padding-left: 8px;
}
@media (min-width: 600px) {
  .edit-widgets-header-toolbar__inserter-toggle.edit-widgets-header-toolbar__inserter-toggle {
    padding-right: 12px;
    padding-left: 12px;
  }
}
.edit-widgets-header-toolbar__inserter-toggle.edit-widgets-header-toolbar__inserter-toggle::after {
  content: none;
}
@media not (prefers-reduced-motion) {
  .edit-widgets-header-toolbar__inserter-toggle.edit-widgets-header-toolbar__inserter-toggle svg {
    transition: transform cubic-bezier(0.165, 0.84, 0.44, 1) 0.2s;
  }
}
.edit-widgets-header-toolbar__inserter-toggle.edit-widgets-header-toolbar__inserter-toggle.is-pressed svg {
  transform: rotate(-45deg);
}

.edit-widgets-keyboard-shortcut-help-modal__section {
  margin: 0 0 2rem 0;
}
.edit-widgets-keyboard-shortcut-help-modal__section-title {
  font-size: 0.9rem;
  font-weight: 600;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut {
  display: flex;
  align-items: baseline;
  padding: 0.6rem 0;
  border-top: 1px solid #ddd;
  margin-bottom: 0;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut:last-child {
  border-bottom: 1px solid #ddd;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut:empty {
  display: none;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut-term {
  font-weight: 600;
  margin: 0 1rem 0 0;
  text-align: left;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut-description {
  flex: 1;
  margin: 0;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut-key-combination {
  display: block;
  background: none;
  margin: 0;
  padding: 0;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut-key-combination + .edit-widgets-keyboard-shortcut-help-modal__shortcut-key-combination {
  margin-top: 10px;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut-key {
  padding: 0.25rem 0.5rem;
  border-radius: 8%;
  margin: 0 0.2rem 0 0.2rem;
}
.edit-widgets-keyboard-shortcut-help-modal__shortcut-key:last-child {
  margin: 0 0.2rem 0 0;
}

.components-panel__header.edit-widgets-sidebar__panel-tabs {
  padding-right: 0;
}

.edit-widgets-widget-areas__top-container {
  display: flex;
  padding: 16px;
}
.edit-widgets-widget-areas__top-container .block-editor-block-icon {
  margin-left: 16px;
}

.edit-widgets-notices__snackbar {
  position: fixed;
  bottom: 24px;
  right: 0;
  left: 0;
  padding-inline: 16px;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  pointer-events: none;
}
.edit-widgets-notices__snackbar .components-snackbar {
  margin-inline: auto;
}

.edit-widgets-layout__inserter-panel {
  height: 100%;
  display: flex;
  flex-direction: column;
}
.edit-widgets-layout__inserter-panel .block-editor-inserter__menu {
  overflow: hidden;
}

.edit-widgets-layout__inserter-panel-content {
  height: calc(100% - 36px - 8px);
}
.edit-widgets-layout__inserter-panel-content .block-editor-inserter__tablist-and-close {
  display: none;
}
@media (min-width: 782px) {
  .edit-widgets-layout__inserter-panel-content {
    height: 100%;
  }
}

.components-popover.more-menu-dropdown__content {
  z-index: 99998;
}

.edit-widgets-welcome-guide {
  width: 312px;
}
.edit-widgets-welcome-guide__image {
  background: #00a0d2;
  margin: 0 0 16px;
}
.edit-widgets-welcome-guide__image > img {
  display: block;
  max-width: 100%;
  object-fit: cover;
}
.edit-widgets-welcome-guide__heading {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 24px;
  line-height: 1.4;
  margin: 16px 0 16px 0;
  padding: 0 32px;
}
.edit-widgets-welcome-guide__text {
  font-size: 13px;
  line-height: 1.4;
  margin: 0 0 24px 0;
  padding: 0 32px;
}
.edit-widgets-welcome-guide__inserter-icon {
  margin: 0 4px;
  vertical-align: text-top;
}
.edit-widgets-welcome-guide .components-button:hover svg {
  fill: #fff;
}

.edit-widgets-block-editor {
  position: relative;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  display: flex;
  flex-direction: column;
  flex-grow: 1;
}
.edit-widgets-block-editor > div:last-of-type,
.edit-widgets-block-editor .block-editor-writing-flow {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
}
.edit-widgets-block-editor .edit-widgets-main-block-list {
  height: 100%;
}
.edit-widgets-block-editor .components-button {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 13px;
}
.edit-widgets-block-editor .components-button.is-tertiary, .edit-widgets-block-editor .components-button.has-icon {
  padding: 6px;
}

.edit-widgets-editor__list-view-panel {
  height: 100%;
  display: flex;
  flex-direction: column;
  min-width: 350px;
}

.edit-widgets-editor__list-view-panel-content {
  height: calc(100% - 36px - 8px);
  overflow-y: auto;
  padding: 8px;
}

.edit-widgets-editor__list-view-panel-header {
  align-items: center;
  border-bottom: 1px solid #ddd;
  display: flex;
  justify-content: space-between;
  height: 48px;
  padding-right: 16px;
  padding-left: 8px;
}

body.js.appearance_page_gutenberg-widgets,
body.js.widgets-php {
  background: #fff;
}
body.js.appearance_page_gutenberg-widgets #wpcontent,
body.js.widgets-php #wpcontent {
  padding-right: 0;
}
body.js.appearance_page_gutenberg-widgets #wpbody-content,
body.js.widgets-php #wpbody-content {
  padding-bottom: 0;
}
body.js.appearance_page_gutenberg-widgets,
body.js.widgets-php {
  /* We hide legacy notices in Gutenberg Based Pages, because they were not designed in a way that scaled well.
     Plugins can use Gutenberg notices if they need to pass on information to the user when they are editing. */
}
body.js.appearance_page_gutenberg-widgets #wpbody-content > div:not(.blocks-widgets-container):not(#screen-meta),
body.js.widgets-php #wpbody-content > div:not(.blocks-widgets-container):not(#screen-meta) {
  display: none;
}
body.js.appearance_page_gutenberg-widgets #wpfooter,
body.js.widgets-php #wpfooter {
  display: none;
}
body.js.appearance_page_gutenberg-widgets .a11y-speak-region,
body.js.widgets-php .a11y-speak-region {
  right: -1px;
  top: -1px;
}
body.js.appearance_page_gutenberg-widgets ul#adminmenu a.wp-has-current-submenu::after,
body.js.appearance_page_gutenberg-widgets ul#adminmenu > li.current > a.current::after,
body.js.widgets-php ul#adminmenu a.wp-has-current-submenu::after,
body.js.widgets-php ul#adminmenu > li.current > a.current::after {
  border-left-color: #fff;
}
body.js.appearance_page_gutenberg-widgets .media-frame select.attachment-filters:last-of-type,
body.js.widgets-php .media-frame select.attachment-filters:last-of-type {
  width: auto;
  max-width: 100%;
}

.blocks-widgets-container {
  box-sizing: border-box;
}
.blocks-widgets-container *,
.blocks-widgets-container *::before,
.blocks-widgets-container *::after {
  box-sizing: inherit;
}
@media (min-width: 600px) {
  .blocks-widgets-container {
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
    min-height: calc(100vh - 46px);
  }
}
@media (min-width: 782px) {
  .blocks-widgets-container {
    min-height: calc(100vh - 32px);
  }
}
.blocks-widgets-container .interface-interface-skeleton__content {
  background-color: #f0f0f0;
}

.blocks-widgets-container .editor-styles-wrapper {
  max-width: 700px;
  margin: auto;
}

.edit-widgets-sidebar .components-button.interface-complementary-area__pin-unpin-item {
  display: none;
}

.js .widgets-php .notice {
  display: none !important;
}