/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
.wp-block[data-align=center] > .wp-block-icon {
  display: flex;
  justify-content: center;
}

.wp-block-icon__inserter {
  padding: 0 24px;
  margin: 0 -24px;
}

.wp-block-icon__inserter-header {
  align-items: center;
  display: flex;
  justify-content: space-between;
  margin-bottom: 16px;
}

.wp-block-icon__inserter-grid-icons-list {
  display: grid;
  grid-template-columns: repeat(auto-fill, minmax(150px, 1fr));
}

.wp-block-icon__inserter-grid-no-results {
  display: flex;
  justify-content: center;
}

.wp-block-icon__inserter-grid-icons-list-item {
  display: flex;
  flex-direction: column;
  height: auto !important;
}

.wp-block-icon__inserter-grid-icons-list-item-icon {
  padding: 12px;
}

.wp-block-icon__inserter-grid-icons-list-item-title {
  font-size: 12px;
  padding: 4px 4px 8px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.wp-block-icon__toolbar-content {
  width: 250px;
}

.wp-block-icon__placeholder {
  backdrop-filter: blur(100px);
}