.wp-block-query-pagination.is-content-justification-space-between > .wp-block-query-pagination-next:last-of-type {
  margin-inline-start: auto;
}
.wp-block-query-pagination.is-content-justification-space-between > .wp-block-query-pagination-previous:first-child {
  margin-inline-end: auto;
}
.wp-block-query-pagination .wp-block-query-pagination-previous-arrow {
  margin-right: 1ch;
  display: inline-block;
}
.wp-block-query-pagination .wp-block-query-pagination-previous-arrow:not(.is-arrow-chevron) {
  transform: scaleX(1) /*rtl:scaleX(-1);*/;
}
.wp-block-query-pagination .wp-block-query-pagination-next-arrow {
  margin-left: 1ch;
  display: inline-block;
}
.wp-block-query-pagination .wp-block-query-pagination-next-arrow:not(.is-arrow-chevron) {
  transform: scaleX(1) /*rtl:scaleX(-1);*/;
}
.wp-block-query-pagination.aligncenter {
  justify-content: center;
}